==> java-support-7.1.1-sources.jar: net/shibboleth/utilities/java/support/security/IdentifierGenerationStrategy.java <==
/*
 * Licensed to the University Corporation for Advanced Internet Development, 
 * Inc. (UCAID) under one or more contributor license agreements.  See the 
 * NOTICE file distributed with this work for additional information regarding
 * copyright ownership. The UCAID licenses this file to You under the Apache 
 * License, Version 2.0 (the "License"); you may not use this file except in 
 * compliance with the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package net.shibboleth.utilities.java.support.security;

import javax.annotation.Nonnull;

/**
 * Interface for identifier generators. This identifier can be used for things like digital signature identifiers,
 * opaque principal identifiers, etc.
 */
public interface IdentifierGenerationStrategy {

    /**
     * Generates an identifier guaranteed to be XML ID safe.
     * 
     * @return the identifier
     */
    @Nonnull public String generateIdentifier();

    /**
     * Generates an identifier.
     * 
     * @param xmlSafe true iff the result must be XML ID safe
     * @return the identifier
     */
    @Nonnull public String generateIdentifier(boolean xmlSafe);
}

==> java-support-8.0.0-sources.jar: net/shibboleth/utilities/java/support/security/IdentifierGenerationStrategy.java <==
/*
 * Licensed to the University Corporation for Advanced Internet Development,
 * Inc. (UCAID) under one or more contributor license agreements.  See the
 * NOTICE file distributed with this work for additional information regarding
 * copyright ownership. The UCAID licenses this file to You under the Apache
 * License, Version 2.0 (the "License"); you may not use this file except in
 * compliance with the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package net.shibboleth.utilities.java.support.security;

import javax.annotation.Nonnull;

import net.shibboleth.utilities.java.support.annotation.constraint.NotEmpty;

/**
 * Interface for identifier generators. This identifier can be used for things like digital signature identifiers,
 * opaque principal identifiers, etc.
 */
public interface IdentifierGenerationStrategy {

    /**
     * Generates an identifier guaranteed to be XML ID safe.
     * 
     * @return the identifier
     */
    @Nonnull @NotEmpty public String generateIdentifier();

    /**
     * Generates an identifier.
     * 
     * @param xmlSafe true iff the result must be XML ID safe
     * @return the identifier
     */
    @Nonnull @NotEmpty public String generateIdentifier(boolean xmlSafe);
}
